@@ -141,7 +141,7 @@ class SantaMonicaScraper(EngageScraper):
         agenda_ids_to_scrape = list(filter(
             lambda x: x not in meetings_already_scraped, agenda_meeting_ids_available))
         if SCRAPER_DEBUG:
-            log.error(agenda_ids_to_scrape)
+            log.error(f"AGENDA IDS TO SCRAPE: {agenda_ids_to_scrape}")
 
         # Since we don't want to scrape everything just scrape what we need
         updated_agenda_locations = [
@@ -428,41 +428,44 @@ class SantaMonicaScraper(EngageScraper):
         session = self._DBsession()
         try:
             for item in agenda_dict["items"]:
-                new_agenda_item = AgendaItem(
-                    title=item["title"],
-                    department=item["department"],
-                    body=item["body"],
-                    sponsors=item["sponsors"],
-                    agenda_id=agenda_saved.id,
-                    meeting_time=item["meeting_time"],
-                    agenda_item_id=item["agenda_item_id"]
-                )
-                session.add(new_agenda_item)
-                session.commit()
-                # need id so must commit before next add
-                self._store_agenda_reccommendations(
-                    item["recommendations"], new_agenda_item, session)
+                try:
+                    new_agenda_item = AgendaItem(
+                        title=item["title"],
+                        department=item["department"],
+                        body=item["body"],
+                        sponsors=item["sponsors"],
+                        agenda_id=agenda_saved.id,
+                        meeting_time=item["meeting_time"],
+                        agenda_item_id=item["agenda_item_id"]
+                    )
+                    session.add(new_agenda_item)
+                    session.commit()
+                    # need id so must commit before next add
+                    self._store_agenda_reccommendations(
+                        item["recommendations"], new_agenda_item, session)
 
-                # load item to elasticsearch
-                if ES_ENABLED:
-                    es_item = {
-                        'date': item["meeting_time"],
-                        'agenda_item_id': item["agenda_item_id"],
-                        'agenda_id': agenda_saved.id,
-                        'title': item["title"],
-                        'recommendations': item["recommendations"],
-                        'body': item["body"],
-                        'department': item["department"],
-                        'sponsors': item["sponsors"],
-                        'tags': None,
-                        'committee': self._Committee.name,
-                        'committee_id': self._Committee.id,
-                    }
-
-                    es_load = self._elasticsearch_utility.postItem(es_item)
-                    if SCRAPER_DEBUG:
-                        log.info(es_load)
+                    # load item to elasticsearch
+                    if ES_ENABLED:
+                        es_item = {
+                            'date': item["meeting_time"],
+                            'agenda_item_id': item["agenda_item_id"],
+                            'agenda_id': agenda_saved.id,
+                            'title': item["title"],
+                            'recommendations': item["recommendations"],
+                            'body': item["body"],
+                            'department': item["department"],
+                            'sponsors': item["sponsors"],
+                            'tags': None,
+                            'committee': self._Committee.name,
+                            'committee_id': self._Committee.id,
+                        }
 
+                        es_load = self._elasticsearch_utility.postItem(es_item)
+                        if SCRAPER_DEBUG:
+                            log.info(es_load)
+                except Exception as itemExc:
+                    agendaitem = item["agenda_item_id"]
+                    log.error(f"Could not add item {agendaitem} with {itemExc}")
         except Exception as exc:
             log.error(
                 "Something happened when adding agenda items from agenda {}: {}".format(agenda_saved.id, str(exc)))
